This module contains python code for the analysis and figures for paper
[Stochastic Volatility for Factor Heath-Jarrow-Morton Framework](https://papers.ssrn.com/sol3/papers.cfm?abstract_id=4646925)
by Artur Sepp and Parviz Rakhmonov



See the description of data and analysis in the paper.

Figures in the paper are generated using unittests in
```python 
calibration_fig_5_6_7.py
calibration_fig_8_9.py
```
https://github.com/ArturSepp/StochVolModels/tree/main/my_papers/sv_for_factor_hjm

See the description of data and analysis in the paper.